@@ -72,6 +72,7 @@ class TestArgs(object):
     package_version = ''
     murano_repo_url = 'http://127.0.0.1'
     exists_action = ''
+    dep_exists_action = ''
     is_public = False
     categories = []
 
@@ -500,10 +501,24 @@ class ShellCommandTest(ShellTest):
         self.make_env()
         self.register_keystone_discovery_fixture(m_requests)
         self.register_keystone_token_fixture(m_requests)
-        self.shell('environment-action-call 12345 --action-id 54321 '
-                   '--arguments foo=bar')
+        self.shell("""environment-action-call 12345 --action-id 54321
+                   --arguments foo=bar
+                   dictArg={"key1":"value1","key2":"value2"}
+                   listArg=["item1","item2","item3"]
+                   nullArg=null
+                   stringArg="null"
+                   intArg=5
+                   compoundArg=["foo",14,{"key1":null,"key2":8}]""")
         self.client.actions.call.assert_called_once_with(
-            '12345', '54321', arguments={'foo': 'bar'})
+            '12345', '54321', arguments={
+                'foo': 'bar',
+                'dictArg': {u'key1': u'value1', u'key2': u'value2'},
+                'listArg': [u'item1', u'item2', u'item3'],
+                'nullArg': None,
+                'stringArg': u'null',
+                'intArg': 5,
+                'compoundArg': [u'foo', 14, {u'key1': None, u'key2': 8}]
+            })
 
     @mock.patch('muranoclient.v1.actions.ActionManager')
     @requests_mock.mock()
@@ -516,6 +531,129 @@ class ShellCommandTest(ShellTest):
         self.client.actions.get_result.assert_called_once_with(
             '12345', '54321')
 
+    @mock.patch('muranoclient.v1.static_actions.StaticActionManager')
+    @requests_mock.mock()
+    def test_static_action_call_basic(self, mock_manager, m_requests):
+        self.client.static_actions = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell('static-action-call class.name method.name')
+        self.client.static_actions.call.assert_called_once_with({
+            "className": 'class.name',
+            "methodName": 'method.name',
+            "packageName": None,
+            "classVersion": '=0',
+            "parameters": {}
+        })
+
+    @mock.patch('muranoclient.v1.static_actions.StaticActionManager')
+    @requests_mock.mock()
+    def test_static_action_call_full(self, mock_manager, m_requests):
+        self.client.static_actions = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell('static-action-call class.name method.name '
+                   '--package-name package.name --class-version ">1"')
+        self.client.static_actions.call.assert_called_once_with({
+            "className": 'class.name',
+            "methodName": 'method.name',
+            "packageName": 'package.name',
+            "classVersion": '">1"',
+            "parameters": {}
+        })
+
+    @mock.patch('muranoclient.v1.static_actions.StaticActionManager')
+    @requests_mock.mock()
+    def test_static_action_call_string_args(self, mock_manager, m_requests):
+        self.client.static_actions = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell('static-action-call class.name method.name '
+                   '--arguments food=spam parrot=dead')
+        self.client.static_actions.call.assert_called_once_with({
+            "className": 'class.name',
+            "methodName": 'method.name',
+            "packageName": None,
+            "classVersion": '=0',
+            "parameters": {'food': 'spam', 'parrot': 'dead'}
+        })
+
+    @mock.patch('muranoclient.v1.static_actions.StaticActionManager')
+    @requests_mock.mock()
+    def test_static_action_call_json_args(self, mock_manager, m_requests):
+        self.client.static_actions = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell("""static-action-call class.name method.name
+                   --arguments
+                   dictArg={"key1":"value1","key2":"value2"}
+                   listArg=["item1","item2","item3"]
+                   nullArg=null
+                   stringArg="null"
+                   intArg=5
+                   compoundArg=["foo",14,{"key1":null,"key2":8}]""")
+        self.client.static_actions.call.assert_called_once_with({
+            "className": 'class.name',
+            "methodName": 'method.name',
+            "packageName": None,
+            "classVersion": '=0',
+            "parameters": {
+                'dictArg': {u'key1': u'value1', u'key2': u'value2'},
+                'listArg': [u'item1', u'item2', u'item3'],
+                'nullArg': None,
+                'stringArg': u'null',
+                'intArg': 5,
+                'compoundArg': [u'foo', 14, {u'key1': None, u'key2': 8}]
+            }
+        })
+
+    @mock.patch('muranoclient.v1.schemas.SchemaManager')
+    @requests_mock.mock()
+    def test_class_schema(self, mock_manager, m_requests):
+        self.client.schemas = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell('class-schema class.name')
+        self.client.schemas.get.assert_called_once_with(
+            'class.name', [],
+            package_name=None,
+            class_version='=0'
+        )
+
+    @mock.patch('muranoclient.v1.schemas.SchemaManager')
+    @requests_mock.mock()
+    def test_class_schema_with_methods(self, mock_manager, m_requests):
+        self.client.schemas = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell('class-schema class.name method1 method2')
+        self.client.schemas.get.assert_called_once_with(
+            'class.name', ['method1', 'method2'],
+            package_name=None,
+            class_version='=0'
+        )
+
+    @mock.patch('muranoclient.v1.schemas.SchemaManager')
+    @requests_mock.mock()
+    def test_class_schema_full(self, mock_manager, m_requests):
+        self.client.schemas = mock_manager()
+        self.make_env()
+        self.register_keystone_discovery_fixture(m_requests)
+        self.register_keystone_token_fixture(m_requests)
+        self.shell('class-schema class.name method1 method2 '
+                   '--class-version >1.2.3 --package-name foo.bar')
+        self.client.schemas.get.assert_called_once_with(
+            'class.name', ['method1', 'method2'],
+            package_name='foo.bar',
+            class_version='>1.2.3'
+        )
+
     @mock.patch('muranoclient.v1.templates.EnvTemplateManager')
     @requests_mock.mock()
     def test_env_template_delete(self, mock_manager, m_requests):
@@ -693,10 +831,12 @@ class ShellCommandTest(ShellTest):
             self.assertIn(r, result[0])
         self.client.categories.list.assert_called_once_with()
 
+    @mock.patch('muranoclient.v1.packages.PackageManager')
     @mock.patch('muranoclient.v1.categories.CategoryManager')
     @requests_mock.mock()
-    def test_category_show(self, mock_manager, m_requests):
-        self.client.categories = mock_manager()
+    def test_category_show(self, category_manager, pkg_manager, m_requests):
+        self.client.packages = pkg_manager()
+        self.client.categories = category_manager()
         self.make_env()
         self.register_keystone_discovery_fixture(m_requests)
         self.register_keystone_token_fixture(m_requests)
@@ -928,6 +1068,85 @@ class ShellPackagesOperations(ShellCommandTest):
         self.assertEqual(2, self.client.packages.create.call_count)
         self.assertFalse(raw_input_mock.called)
 
+    def _test_conflict_dep(self,
+                           packages, from_file,
+                           dep_exists_action=''):
+        packages.create = mock.MagicMock(
+            side_effect=[common_exceptions.HTTPConflict("Conflict"),
+                         common_exceptions.HTTPConflict("Conflict"),
+                         None])
+
+        packages.filter.return_value = [mock.Mock(id='test_id')]
+
+        args = TestArgs()
+        args.exists_action = 's'
+        args.dep_exists_action = dep_exists_action
+        args.filename = ['first_app']
+
+        pkg1 = make_pkg(
+            {'FullName': 'first_app', 'Require': {'second_app': '1.0'}, })
+        pkg2 = make_pkg({'FullName': 'second_app', })
+
+        def side_effect(name):
+            if 'first_app' in name:
+                return utils.Package(utils.File(pkg1))
+            if 'second_app' in name:
+                return utils.Package(utils.File(pkg2))
+
+        from_file.side_effect = side_effect
+
+        v1_shell.do_package_import(self.client, args)
+
+    @mock.patch('muranoclient.common.utils.Package.from_file')
+    def test_package_import_conflict_dep_skip_ea(self, from_file):
+        self._test_conflict_dep(
+            self.client.packages,
+            from_file,
+            dep_exists_action='s',
+        )
+
+        self.client.packages.create.assert_has_calls(
+            [
+                mock.call({'is_public': False}, {'first_app': mock.ANY}),
+                mock.call({'is_public': False}, {'second_app': mock.ANY}),
+            ], any_order=True,
+        )
+
+        self.assertEqual(2, self.client.packages.create.call_count)
+
+    @mock.patch('muranoclient.common.utils.Package.from_file')
+    def test_package_import_conflict_dep_abort_ea(self, from_file):
+        self.assertRaises(SystemExit, self._test_conflict_dep,
+                          self.client.packages,
+                          from_file,
+                          dep_exists_action='a',
+                          )
+
+        self.client.packages.create.assert_called_with({
+            'is_public': False,
+        }, {'second_app': mock.ANY},)
+
+    @mock.patch('muranoclient.common.utils.Package.from_file')
+    def test_package_import_conflict_dep_update_ea(self, from_file):
+        self._test_conflict_dep(
+            self.client.packages,
+            from_file,
+            dep_exists_action='u',
+        )
+
+        self.assertEqual(True, self.client.packages.delete.called)
+
+        self.client.packages.create.assert_has_calls(
+            [
+                mock.call({'is_public': False}, {'first_app': mock.ANY}),
+                mock.call({'is_public': False}, {'second_app': mock.ANY}),
+                mock.call({'is_public': False}, {'second_app': mock.ANY}),
+            ], any_order=True,
+        )
+
+        self.assertEqual(True, self.client.packages.create.call_count > 2)
+        self.assertEqual(True, self.client.packages.create.call_count < 5)
+
     @mock.patch('muranoclient.common.utils.Package.from_file')
     def test_package_import_no_categories(self, from_file):
         args = TestArgs()
@@ -1053,7 +1272,9 @@ class ShellPackagesOperations(ShellCommandTest):
 
     @requests_mock.mock()
     def test_import_bundle_dependencies(self, m):
-        """Asserts bundle import calls packages create once for each pkg,
+        """Test bundle import calls
+
+        Asserts bundle import calls packages create once for each pkg,
         including dependencies.
         """
         pkg1 = make_pkg(
