@@ -12,12 +12,15 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import collections
+
 from glanceclient import exc as glance_exc
 import six
 import yaml
 
 from muranoclient.common import exceptions as exc
 from muranoclient.common import utils
+from muranoclient.i18n import _
 
 
 def rewrap_http_exceptions(func):
@@ -51,7 +54,25 @@ class ArtifactRepo(object):
         for k, v in six.iteritems(kwargs):
             package_draft[k] = v
 
-        inherits = self._get_local_inheritance(package.classes)
+        inherits = self._get_local_inheritance(package.classes,
+                                               package.resolvers)
+
+        # check for global inheritance
+        ancestor_queue = collections.deque(inherits.keys())
+        while ancestor_queue:
+            ancestor_name = ancestor_queue.popleft()
+            child_classes = inherits[ancestor_name]
+
+            ancestors = self.list(class_definitions=ancestor_name)
+            for ancestor in ancestors:
+                # check if ancestor inherits anything
+                ancestor_inherits = \
+                    ancestor.type_specific_properties.get('inherits', {})
+                for name, value in ancestor_inherits.items():
+                    # check if this is the class we actually inherit
+                    if ancestor_name in value:
+                        ancestor_queue.append(name)
+                        inherits[name] = child_classes
 
         package_draft['inherits'] = inherits
 
@@ -62,8 +83,8 @@ class ArtifactRepo(object):
 
         # NOTE(ativelkov): this is very racy, but until we have a chance to
         # enforce uniqueness right in glance this is the only way to do it
-        is_public = package_draft.get('visibility', 'private')
-        if is_public:
+        visibility = package_draft.get('visibility', 'private')
+        if visibility == 'public':
             filters = {}
         else:
             filters = {'owner': self.tenant}
@@ -89,16 +110,16 @@ class ArtifactRepo(object):
         return self.client.artifacts.get(app_id)
 
     @staticmethod
-    def _get_local_inheritance(classes):
+    def _get_local_inheritance(classes, resolvers):
         result = {}
         for class_name, klass in six.iteritems(classes):
             if 'Extends' not in klass:
                 continue
             ns = klass.get('Namespaces')
             if ns:
-                resolver = NamespaceResolver(ns)
+                resolver = utils.NamespaceResolver(ns)
             else:
-                resolver = None
+                resolver = resolvers.get(class_name)
 
             if isinstance(klass['Extends'], list):
                 bases = klass['Extends']
@@ -189,7 +210,7 @@ class ArtifactRepo(object):
         ui_stream = "".join(
             self.client.artifacts.download_blob(app_id, 'ui_definition'))
         if loader_cls is None:
-            loader_cls = yaml.Loader
+            loader_cls = yaml.SafeLoader
         return yaml.load(ui_stream, loader_cls)
 
     def get_logo(self, app_id):
@@ -281,7 +302,7 @@ class PackageManagerAdapter(object):
 
     @rewrap_http_exceptions
     def get_ui(self, app_id, loader_cls=None):
-        return self.glare.get_ui(app_id, loader_cls)
+        return self.legacy.get_ui(app_id, loader_cls)
 
 
 class PackageWrapper(object):
@@ -325,33 +346,14 @@ class PackageWrapper(object):
             return getattr(self._item, name)
 
     def to_dict(self):
-        return {'id': self.id, 'name': self.name, 'owner_id': self.owner_id}
-
-
-class NamespaceResolver(object):
-    """Copied from main murano repo
-
-    original at murano/dsl/namespace_resolver.py
-    """
-
-    def __init__(self, namespaces):
-        self._namespaces = namespaces
-        self._namespaces[''] = ''
-
-    def resolve_name(self, name, relative=None):
-        if name is None:
-            raise ValueError()
-        if name and name.startswith(':'):
-            return name[1:]
-        if ':' in name:
-            parts = name.split(':')
-            if len(parts) != 2 or not parts[1]:
-                raise NameError('Incorrectly formatted name ' + name)
-            if parts[0] not in self._namespaces:
-                raise KeyError('Unknown namespace prefix ' + parts[0])
-            return '.'.join((self._namespaces[parts[0]], parts[1]))
-        if not relative and '=' in self._namespaces and '.' not in name:
-            return '.'.join((self._namespaces['='], name))
-        if relative and '.' not in name:
-            return '.'.join((relative, name))
-        return name
+        keys = ('author', 'categories', 'class_definitions', 'created',
+                'description', 'enabled', 'fully_qualified_name', 'id',
+                'is_public', 'name', 'owner_id', 'tags', 'type',
+                'updated')
+        missing_keys = [key for key in keys if not hasattr(self, key)]
+        if missing_keys:
+            raise KeyError(_("Some attributes are missing in "
+                             "%(pkg_name)s: %(attrs)s.") %
+                           {'pkg_name': self.name,
+                            'attrs': ", ".join(missing_keys)})
+        return {key: getattr(self, key) for key in keys}
